pub fn format_python_error(
py: Python<'_>,
err: &PyErr,
func: &CompiledFunction,
) -> StringExpand description
Format a Python error with context from the compiled function.
pub fn format_python_error(
py: Python<'_>,
err: &PyErr,
func: &CompiledFunction,
) -> StringFormat a Python error with context from the compiled function.