Module marshaling

Module marshaling 

WireValue <-> Python object conversion.

Functions

msgpack_to_pyobject
Convert an rmpv::Value to a Python object.
pyobject_to_msgpack
Convert a Python object to an rmpv::Value (untyped path).
pyobject_to_typed_msgpack
Convert a Python object to an rmpv::Value using the declared Shape return type for validation and coercion.
shape_type_to_python_hint
Shape type name -> Python type hint string.
strip_result_wrapper
Strip Result<...> wrapper from a type string, returning the inner type.