WireValue <-> Python object conversion.
Functions
- msgpack_
to_ pyobject - Convert an rmpv::Value to a Python object.
- pyobject_
to_ msgpack - Convert a Python object to an rmpv::Value (untyped path).
- pyobject_
to_ typed_ msgpack - Convert a Python object to an rmpv::Value using the declared Shape return type for validation and coercion.
- shape_
type_ to_ python_ hint - Shape type name -> Python type hint string.
- strip_
result_ wrapper - Strip
Result<...>wrapper from a type string, returning the inner type.